@@ -14,7 +14,11 @@ __PACKAGE__->add_columns(
     hidden_col     => { data_type => "INTEGER" },
     text_col       => { data_type => "TEXT" },
     password_col   => { data_type => "TEXT" },
-    checkbox_col   => { data_type => "TEXT" },
+    checkbox_col   => {
+        data_type => "TEXT",
+        default_value => 0,
+        is_nullable   => 0,
+    },
     select_col     => { data_type => "TEXT" },
     radio_col      => { data_type => "TEXT" },
     radiogroup_col => { data_type => "TEXT" },
